@@ -2,9 +2,9 @@ import numpy as np
 from torchvision import transforms
 from wpcv.utils.data_aug import img_aug, random_float_generator
 from wpcv.utils.ops import pil_ops
-from wcf.packages.template import Predictor,PredictConfigBase,load_image_files,test,TestConfigBase
-from wcf.packages.resnet.dataset import load_image_files
-from wcf.packages.resnet.testing import test,TestConfigBase
+from wcf import Predictor,PredictConfigBase,load_image_files,test,TestConfigBase
+from wcf import load_image_files
+from wcf import test,TestConfigBase
 from wk import remake
 import wk
 import cv2
